==> haskell-primes-0.2.1.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-3zkUgTTSLp41lfHHsssO2V
key:                  primes-0.2.1.0-3zkUgTTSLp41lfHHsssO2V
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  c03586302affd4828d1bbe1628db1868
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-8.10.1/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/primes-0.2.1.0
hs-libraries:         HSprimes-0.2.1.0-3zkUgTTSLp41lfHHsssO2V
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primes-0.2.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-WtJsffRfUeEFKYydZzFr1
key:                  primes-0.2.1.0-WtJsffRfUeEFKYydZzFr1
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  47aa3854f6d0281195147153ef4a9676
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/primes-0.2.1.0
hs-libraries:         HSprimes-0.2.1.0-WtJsffRfUeEFKYydZzFr1
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
